@@ -245,6 +245,11 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			av: reflected type, valid char
 		*/
 
+		// set vStatus
+		for k, _ := range params {
+			vStatus[k] = false
+		}
+
 		// set path base XSS
 		for k, v := range options.PathReflection {
 			if strings.Contains(v, "Injected:") {
@@ -281,6 +286,39 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			}
 		}
 
+		// Custom Payload
+		if isAllowType(policy["Content-Type"]) && options.CustomPayloadFile != "" {
+			ff, err := readLinesOrLiteral(options.CustomPayloadFile)
+			if err != nil {
+				printing.DalLog("SYSTEM", "Custom XSS payload load fail..", options)
+			} else {
+				for _, customPayload := range ff {
+					if customPayload != "" {
+						for k, v := range params {
+							if optimization.CheckInspectionParam(options, k) {
+								ptype := ""
+								for _, av := range v {
+									if strings.Contains(av, "PTYPE:") {
+										ptype = GetPType(av)
+									}
+								}
+								// Add plain XSS Query
+								tq, tm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "NaN", options)
+								query[tq] = tm
+								// Add URL encoded XSS Query
+								etq, etm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
+								query[etq] = etm
+								// Add HTML Encoded XSS Query
+								htq, htm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
+								query[htq] = htm
+							}
+						}
+					}
+				}
+				printing.DalLog("SYSTEM", "Added your "+strconv.Itoa(len(ff))+" custom xss payload", options)
+			}
+		}
+
 		if isAllowType(policy["Content-Type"]) && !options.OnlyCustomPayload {
 			// Set common payloads
 			cu, err := url.Parse(target)
@@ -303,7 +341,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			}
 
 			for v := range cp {
-				if optimization.CheckUniqParam(options, v) {
+				if optimization.CheckInspectionParam(options, v) {
 					cpArr = append(cpArr, v)
 					arc := optimization.SetPayloadValue(getCommonPayload(), options)
 					for _, avv := range arc {
@@ -321,7 +359,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			}
 
 			for v := range cpd {
-				if optimization.CheckUniqParam(options, v) {
+				if optimization.CheckInspectionParam(options, v) {
 					cpdArr = append(cpdArr, v)
 					arc := optimization.SetPayloadValue(getCommonPayload(), options)
 					for _, avv := range arc {
@@ -348,7 +386,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 				}
 				dpayloads := optimization.SetPayloadValue(dlst, options)
 				for v := range cp {
-					if optimization.CheckUniqParam(options, v) {
+					if optimization.CheckInspectionParam(options, v) {
 						// loop payload list
 						if len(params[v]) == 0 {
 							for _, dpayload := range dpayloads {
@@ -370,7 +408,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 					}
 				}
 				for v := range cpd {
-					if optimization.CheckUniqParam(options, v) {
+					if optimization.CheckInspectionParam(options, v) {
 						// loop payload list
 						if len(params[v]) == 0 {
 							for _, dpayload := range dpayloads {
@@ -395,8 +433,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 
 			// Set param base xss
 			for k, v := range params {
-				if optimization.CheckUniqParam(options, k) {
-					vStatus[k] = false
+				if optimization.CheckInspectionParam(options, k) {
 					ptype := ""
 					chars := GetSpecialChar()
 					var badchars []string
@@ -487,7 +524,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 
 			// loop parameter list
 			for k, v := range params {
-				if optimization.CheckUniqParam(options, k) {
+				if optimization.CheckInspectionParam(options, k) {
 					ptype := ""
 					for _, av := range v {
 						if strings.Contains(av, "PTYPE:") {
@@ -530,10 +567,10 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 				}
 				if line != "" {
 					printing.DalLog("INFO", "A '"+endpoint+"' payloads has been loaded ["+line+"L / "+size+"]               ", options)
-					for _, customPayload := range payload {
-						if customPayload != "" {
+					for _, remotePayload := range payload {
+						if remotePayload != "" {
 							for k, v := range params {
-								if optimization.CheckUniqParam(options, k) {
+								if optimization.CheckInspectionParam(options, k) {
 									ptype := ""
 									for _, av := range v {
 										if strings.Contains(av, "PTYPE:") {
@@ -541,13 +578,13 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 										}
 									}
 									// Add plain XSS Query
-									tq, tm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "NaN", options)
+									tq, tm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "NaN", options)
 									query[tq] = tm
 									// Add URL encoded XSS Query
-									etq, etm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
+									etq, etm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
 									query[etq] = etm
 									// Add HTML Encoded XSS Query
-									htq, htm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
+									htq, htm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
 									query[htq] = htm
 								}
 							}
@@ -559,39 +596,6 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			}
 		}
 
-		// Custom Payload
-		if options.CustomPayloadFile != "" {
-			ff, err := readLinesOrLiteral(options.CustomPayloadFile)
-			if err != nil {
-				printing.DalLog("SYSTEM", "Custom XSS payload load fail..", options)
-			} else {
-				for _, customPayload := range ff {
-					if customPayload != "" {
-						for k, v := range params {
-							if optimization.CheckUniqParam(options, k) {
-								ptype := ""
-								for _, av := range v {
-									if strings.Contains(av, "PTYPE:") {
-										ptype = GetPType(av)
-									}
-								}
-								// Add plain XSS Query
-								tq, tm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "NaN", options)
-								query[tq] = tm
-								// Add URL encoded XSS Query
-								etq, etm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
-								query[etq] = etm
-								// Add HTML Encoded XSS Query
-								htq, htm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
-								query[htq] = htm
-							}
-						}
-					}
-				}
-				printing.DalLog("SYSTEM", "Added your "+strconv.Itoa(len(ff))+" custom xss payload", options)
-			}
-		}
-
 		printing.DalLog("SYSTEM", "Start XSS Scanning.. with "+strconv.Itoa(len(query))+" queries 🗡", options)
 		queryCount := 0
 		printing.DalLog("SYSTEM", "[ Make "+strconv.Itoa(options.Concurrence)+" workers ] [ Allocated "+strconv.Itoa(len(query))+" queries ]", options)
